@@ -11,6 +11,7 @@ from omas import *
 
 # set OMAS_DEBUG_TOPIC to see when data is loaded dynamically
 os.environ['OMAS_DEBUG_TOPIC'] = 'dynamic'
+os.environ['USER'] = 'menghio'
 
 # generate some data and save it in IMAS
 ods = ODS().sample(ntimes=2)
@@ -36,11 +37,11 @@ ods.load('test.pkl')
 # the data that was loaded is stored in the pickle
 print(ods.flat().keys())
 
-# re-open the file descriptor to continue loading more data
-with ods.open():
+# continue loading more data
+with ods.open('imas', os.environ['USER'], 'DIII-D', 1000, 0):
     print(ods['equilibrium.time'])
 
 # dynamic load can also tell us what IMAS elements have data
-with ods.open():
+with ods.open('imas', os.environ['USER'], 'DIII-D', 1000, 0):
     print(ods.keys(dynamic=True))
     print(ods['equilibrium.time_slice.0.profiles_1d'].keys(dynamic=True))
