@@ -31,6 +31,7 @@ try:
 except ImportError as _excp:
     failed_PINT = _excp
 
+
 class TestOmasPhysics(unittest.TestCase):
     """
     Test suite for omas_physics.py
@@ -41,24 +42,26 @@ class TestOmasPhysics(unittest.TestCase):
         ods.sample_equilibrium()
 
         assert "energy_mhd" not in ods['equilibrium.time_slice.0.global_quantities']
-        ods = equilibrium_consistent(ods)
-        assert ("energy_mhd" in ods['equilibrium.time_slice.0.global_quantities']) and (ods['equilibrium.time_slice.0.global_quantities.energy_mhd'] > 0)
+        ods.physics_equilibrium_consistent()
+        assert ("energy_mhd" in ods['equilibrium.time_slice.0.global_quantities']) and (
+            ods['equilibrium.time_slice.0.global_quantities.energy_mhd'] > 0
+        )
         return
 
     def test_core_profiles_pressures(self):
         ods = ODS()
         ods.sample_core_profiles(include_pressure=False)
-        ods2 = core_profiles_pressures(ods, update=True)
+        ods2 = ods.physics_core_profiles_pressures(update=True)
         diff = ods.diff(ods2)
         assert not diff
 
-        ods2 = core_profiles_pressures(ods, update=False)
+        ods2 = ods.physics_core_profiles_pressures(update=False)
         assert all(['press' in item for item in ods2.flat().keys() if not item.endswith('rho_tor_norm')])
         return
 
     def test_core_profiles_currents(self):
 
-        rho = numpy.linspace(0., 1., 4)
+        rho = numpy.linspace(0.0, 1.0, 4)
         Jval = 1e5 * numpy.ones(4)
         jdef = {}
         Js = ['j_actuator', 'j_bootstrap', 'j_non_inductive', 'j_ohmic', 'j_total']
@@ -68,7 +71,7 @@ class TestOmasPhysics(unittest.TestCase):
         def CPC(ods, kw=jdef, should_RE=False, should_AE=False, warn=False):
 
             try:
-                core_profiles_currents(ods, 0, rho, warn=warn, **kw)
+                ods.physics_core_profiles_currents(0, rho, warn=warn, **kw)
             except RuntimeError as err:
                 if should_RE:
                     pass
@@ -95,13 +98,15 @@ class TestOmasPhysics(unittest.TestCase):
             CPC(ODS(), kw=kw, should_RE=(J1 == 'j_actuator'))
 
             # Now try setting two
-            for J2 in Js[i + 1:]:
+            for J2 in Js[i + 1 :]:
                 kw = copy.deepcopy(jdef)
                 kw[J1] = Jval
                 kw[J2] = Jval
-                should_RE = ((not isinstance(kw['j_actuator'], str) or kw['j_actuator'] != 'default') and
-                             (isinstance(kw['j_bootstrap'], str) and kw['j_bootstrap'] == 'default') and
-                             (isinstance(kw['j_non_inductive'], str) and kw['j_non_inductive'] == 'default'))
+                should_RE = (
+                    (not isinstance(kw['j_actuator'], str) or kw['j_actuator'] != 'default')
+                    and (isinstance(kw['j_bootstrap'], str) and kw['j_bootstrap'] == 'default')
+                    and (isinstance(kw['j_non_inductive'], str) and kw['j_non_inductive'] == 'default')
+                )
                 CPC(ODS(), kw=kw, should_RE=should_RE)
 
         # Try setting three
@@ -109,24 +114,22 @@ class TestOmasPhysics(unittest.TestCase):
             kw = copy.deepcopy(jdef)
             for key in keys:
                 kw[key] = Jval
-            if (('j_actuator' in keys) and
-                    ('j_bootstrap' in keys) and
-                    ('j_non_inductive' in keys)):
+            if ('j_actuator' in keys) and ('j_bootstrap' in keys) and ('j_non_inductive' in keys):
                 CPC(ODS(), kw=kw, should_AE=True)
                 kw['j_non_inductive'] = 2 * Jval
-            elif (('j_non_inductive' in keys) and
-                  ('j_ohmic' in keys) and
-                  ('j_total' in keys)):
+            elif ('j_non_inductive' in keys) and ('j_ohmic' in keys) and ('j_total' in keys):
                 CPC(ODS(), kw=kw, should_AE=True)
                 kw['j_total'] = 2 * Jval
             CPC(ODS(), kw=kw)
 
         # Try setting four
-        for dkey, rkey, factor in [('j_total', 'j_non_inductive', 2),
-                                   ('j_ohmic', 'j_non_inductive', 2),
-                                   ('j_non_inductive', 'j_total', 3),
-                                   ('j_bootstrap', 'j_total', 2),
-                                   ('j_actuator', 'j_total', 2)]:
+        for dkey, rkey, factor in [
+            ('j_total', 'j_non_inductive', 2),
+            ('j_ohmic', 'j_non_inductive', 2),
+            ('j_non_inductive', 'j_total', 3),
+            ('j_bootstrap', 'j_total', 2),
+            ('j_actuator', 'j_total', 2),
+        ]:
             kw = copy.deepcopy(jdef)
             for key in kw.keys():
                 if key != dkey:
@@ -147,15 +150,13 @@ class TestOmasPhysics(unittest.TestCase):
 
         # Now test with equilibrium and existing quantities
         ods = ODS().sample_equilibrium()
-        kw = {'j_actuator': Jval,
-              'j_bootstrap': Jval}
+        kw = {'j_actuator': Jval, 'j_bootstrap': Jval}
         CPC(ods, kw=kw)  # j_ni = 2
         kw = {'j_bootstrap': 2 * Jval}
         CPC(ods, kw=kw, should_AE=True)
         kw = {'j_bootstrap': 2 * Jval, 'j_non_inductive': None}
         CPC(ods, kw=kw)  # j_ni = 3
-        kw = {'j_actuator': 1.5 * Jval,
-              'j_bootstrap': 1.5 * Jval}
+        kw = {'j_actuator': 1.5 * Jval, 'j_bootstrap': 1.5 * Jval}
         CPC(ods, kw=kw)
         kw = {'j_bootstrap': 2 * Jval, 'j_actuator': None}
         CPC(ods, kw=kw)
@@ -180,7 +181,7 @@ class TestOmasPhysics(unittest.TestCase):
 
     def test_current_from_eq(self):
         ods = ODS().sample_equilibrium()
-        current_from_eq(ods, 0)
+        ods.physics_current_from_eq(0)
         return
 
     def test_define_cocos(self):
@@ -271,7 +272,7 @@ class TestOmasPhysics(unittest.TestCase):
         return
 
     def test_cocosio(self):
-        x = numpy.linspace(.1, 1, 10)
+        x = numpy.linspace(0.1, 1, 10)
 
         ods = ODS(cocosio=11, cocos=11)
         ods['equilibrium.time_slice.0.profiles_1d.psi'] = x
@@ -374,6 +375,7 @@ class TestOmasPhysics(unittest.TestCase):
     @unittest.skipIf(failed_PINT, str(failed_PINT))
     def test_handle_units(self):
         import pint
+
         ureg = pint.UnitRegistry()
 
         ods = ODS()
@@ -446,7 +448,9 @@ class TestOmasPhysics(unittest.TestCase):
 
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore", message=".*defining its COCOS transform.*")
-            generate_cocos_signals(list_structures(imas_version=omas_rcparams['default_imas_version']), threshold=0, write=False, verbose=False)
+            generate_cocos_signals(
+                list_structures(imas_version=omas_rcparams['default_imas_version']), threshold=0, write=False, verbose=False
+            )
         return
 
     # End of TestOmasPhysics class
